# Tutorials

```{toctree}
:maxdepth: 1

external_modules
```

```{todo}
Currently there are few official tutorials for Torii, however due to it being a fork of [Amaranth] the following tutorials written by the Amaranth community are a good place to start.

 * [Learning FPGA Design with nMigen] by Vivonomicon;
 * ["I want to learn nMigen] by kbob;
 * [A tutorial for using Amaranth HDL] by Robert Baruch.
 * [Graded exercises for Amaranth HDL] by Robert Baruch.
```

[Amaranth]: https://github.com/amaranth-lang/amaranth
[Learning FPGA Design with nMigen]: https://vivonomicon.com/2020/04/14/learning-fpga-design-with-nmigen/
["I want to learn nMigen]: https://github.com/kbob/nmigen-examples
[A tutorial for using Amaranth HDL]: https://github.com/robertbaruch/amaranth-tutorial
[Graded exercises for Amaranth HDL]: https://github.com/robertbaruch/amaranth-exercises
